@@ -1,5 +1,6 @@
 package Crypt::Random::Provider::File; 
 use strict;
+use Carp;
 use Math::Pari qw(pari2num);
 
 
@@ -35,7 +36,11 @@ sub get_data {
 
     my($r, $read, $rt) = ('', 0);
     while ($read < $bytes) {
-        read  RANDOM, $rt, 1;
+        my $howmany = read  RANDOM, $rt, 1;
+        next unless $howmany;
+        if ($howmany == -1) { 
+            croak "Error while reading from $$self{Source}. $!"
+        }
         unless ($skip && $skip =~ /\Q$rt\E/) {
             $r .= $rt; $read++;
         }
